@@ -30,6 +30,7 @@ def filter_options(options):
         "runtime",
         "image",
         "qemu_image",
+        "qemu_binary",
         "save_outputs",
         "log_file",
         "log_file_html",
@@ -253,9 +254,9 @@ def setup_parser() -> argparse.ArgumentParser:
         action="extend",
     )
     group.add_argument(
-        "command",
+        "commands",
         nargs="*",
-        help="Command to run inside the VM",
+        help="Space separated list of commands to run inside the VM",
     )
 
     group = parser.add_argument_group("run options")
@@ -299,6 +300,13 @@ def setup_parser() -> argparse.ArgumentParser:
         "--qemu-image", default=None, help="Use qemu from the given container image"
     )
 
+    group.add_argument(
+        "--qemu-binary",
+        default=None,
+        type=Path,
+        help="Use qemu from the given path",
+    )
+
     group = parser.add_argument_group("output")
     group.add_argument(
         "--save-outputs",
